



def SCULPT_OPTIONS (GROUP):
	import click
	@GROUP.group ("SCULPT")
	def GROUP ():
		pass
		
	import click
	@GROUP.command ("ENTIRE-DRIVE")
	@click.option ('--drive-path', required = True, help = '')
	@click.option ('--drive-bytes', required = True, help = '')
	def EXAMPLE (port):	
		


		return;
		
		
		
	import click
	@GROUP.command ("BYTES")
	@click.option ('--drive-path', required = True, help = '')
	@click.option ('--index-0', required = True, help = '')
	@click.option ('--index-1', required = True, help = '')
	def EXAMPLE (port):	


		return;

	return;
