
'''
	VENTURES:
		
		from BRUNCH.ERASE import ERASE
		
		ERASE ({
			"DRIVE PATH": DRIVE_PATH,
			"SCULPT": {
				"ROUTINES": [{
					"BYTES PER PLATE": 512 * 512,
					"BYTES": "ROUTINE_1"
				},{
					"BYTES PER PLATE": 512 * 512,
					"BYTES": "ROUTINE_2"
				}]
			},
			"SCAN": {
				"BYTES PER PLATE": 512 * 512
			}
		})
'''

import BRUNCH.SCAN as SCAN
import BRUNCH.SCULPT as SCULPT

def ERASE (CARGO):



	return
